<h1>O que é o Crystallize</h1>
<p>O Crystallize é um projeto que Visa a atende de maneira imediata a necessidade de se armazenar dados, tanto para profissionais de Data Science, como também para profissionais do desenvolvimento de softwares em geral que precisam de uma rápida abordagem para o salvamento de seus dados.</p>
<h1>Nossa filosofia</h1>
<p>Este projeto nasceu com o intuito de ser leve e eficaz sem a necessidade de instalação de bibliotecas adicionais. Todo o projeto é de rápida instalação e download sendo realmente uma alternativa muito prática para a essas questões de salvamento de dados no dia a dia dos desenvolvedores de softwares.<p>
____________________________
<h1>What is Crystallize</h1>
Crystallize is an immediate project aimed at the need to also meet data, both for Science professionals and for software development professionals in general who need a quick way to save their data.
<h1>Our philosophy</h1>
<p>This project was born with the intention of being light and efficient without the need to install additional libraries. The entire project is quick to install and download and is really a very practical alternative to these data saving issues in the day to day of software developers.</p>